@@ -568,7 +568,7 @@ class TagRelatedManagerMixin(BaseTagRelatedManager):
                     field_lookup += "__iexact"
                 db_tag, __ = self.tag_model.objects.get_or_create(
                     defaults={"name": tag.name, "protected": False},
-                    **{field_lookup: tag.name}
+                    **{field_lookup: tag.name},
                 )
             db_tags.append(db_tag)
         return db_tags
@@ -576,7 +576,7 @@ class TagRelatedManagerMixin(BaseTagRelatedManager):
     #
     # New set, add, remove and clear, to update tag counts
     #
-    def set(self, *objs):
+    def set(self, objs, **kwargs):
         self.clear()
         self.add(*objs)
 
@@ -663,3 +663,21 @@ class TagRelatedManagerMixin(BaseTagRelatedManager):
         self.tags = []
 
     clear.alters_data = True
+
+    def get_similar_objects(self):
+        """
+        Find similarly tagged objects
+
+        Example::
+
+            related_objects_qs = myobject.tags.get_similar_objects()
+
+        is equivalent to::
+
+            related_objects_qs = MyModel.objects.similarly_tagged(myobject, 'tags')
+        """
+        tagged_model = self.source_field.related_model
+        similar = tagged_model.objects.similarly_tagged(
+            self.instance, field_name=self.prefetch_cache_name
+        )
+        return similar
