@@ -1,11 +1,9 @@
 """
 JSON serializer with Tagulous support
 """
-from __future__ import unicode_literals
-
 from django.core.serializers import json as json_serializer
 
-from tagulous.serializers import base
+from . import base
 
 
 class Serializer(base.SerializerMixin, json_serializer.Serializer):
