@@ -1,11 +1,9 @@
 """
 Python serializer with Tagulous support
 """
-from __future__ import unicode_literals
-
 from django.core.serializers import python as python_serializer
 
-from tagulous.serializers import base
+from . import base
 
 
 class Serializer(base.SerializerMixin, python_serializer.Serializer):
