@@ -1,11 +1,9 @@
 """
 YAML serializer with Tagulous support
 """
-from __future__ import unicode_literals
-
 from django.core.serializers import pyyaml as pyyaml_serializer
 
-from tagulous.serializers import base
+from . import base
 
 
 class Serializer(base.SerializerMixin, pyyaml_serializer.Serializer):
